NAME = "bluer_ugv"

ICON = "🐬"

DESCRIPTION = f"{ICON} AI x ROS."

VERSION = "6.320.1"

REPO_NAME = "bluer-ugv"

MARQUEE = "https://raw.githubusercontent.com/kamangir/assets2/refs/heads/main/bluer-swallow/20250701_2206342_1.gif"

ALIAS = "@ugv"


def fullname() -> str:
    return f"{NAME}-{VERSION}"
